#!/bin/sh
# TODO:
# - Check if installation is successful
# - Check if already installed
# - Uninstall

# main
set_lang
set_version
MISSING="$(check_deps)"

if command -v zenity > /dev/null ; then
    MENU="zenity"
    zenity --title "$TITLE" --text "$PROMPT_WELCOME" --info
    [ -n "$MISSING" ] && zenity --title "$TITLE" --text "$PROMPT_ERR_DEPS $MISSING" --error && exit 1

    # Select file to be downloaded if os can't be determined
    [ -z "$FILE" ] && FILE="$(zenity --title "$TITLE" --text "$PROMPT_FILE" --list \
        --column "$FILENAME" --column "$FILEDESC" \
        "ClientesMAC_rev35.dmg" "macOSX 10.14 o superior" \
        "ClientesLinux_DEB64_Rev25.zip" "Ubuntu 18.04 LTS o superior, Debian 10" \
        "ClientesLinux_CentOS7_Rev6.zip" "CentOS 7" \
        "ClientesLinux_RPM64_Rev24.zip" "Fedora 34 o superior, CentOS Stream 9" \
        --print-column=1)"

    # Serial number is required for download
    SERIAL="$(zenity --title "$TITLE" --text "$PROMPT_SERIAL" --entry)"
    [ -z "$SERIAL" ] && zenity --title "$TITLE" --text "$PROMPT_ERR_SERIAL" --error && exit 1
    # Generate tempkey & Define DOWNLOAD_URL
    TEMPKEY="$(download_iso "$FILE" "$SERIAL" | sed '/tempkey/!d;s/.*tempkey=//g;s/".*$//g')"
    [ -z "$TEMPKEY" ] && zenity --title "$TITLE" --text "$PROMPT_ERR_DOWNLOAD" --error && exit 1
    DOWNLOAD_URL="https://soportefirmadigital.com/sfdj/getiso.aspx?tempkey=$TEMPKEY"
    # Define where to save file
    if [ -d "/tmp" ] ; then
        SAVE_DIR="/tmp/soportefirmadigital"
        mkdir -p "$SAVE_DIR"
    else
        zenity --title "$TITLE" --text "$PROMPT_DIR_FILE" --info
        SAVE_DIR="$(zenity --file-selection --directory)"
    fi
    [ -z "$SAVE_DIR" ] && zenity --title "$TITLE" --text "$PROMPT_ERR_DIR_FILE" --error && exit 1
    SAVE_FILE="$SAVE_DIR/$FILE"

    # Download file & show progress
    SIZE="$(curl -sI "$DOWNLOAD_URL" | sed '/[Cc]ontent-[Ll]ength/!d;s/^.*: //g' | awk '{$1/=1024;printf "%d",$1}')"
    (curl -sL "$DOWNLOAD_URL" -o "$SAVE_FILE") &
    while true ; do
        sleep 0.5
        DOWN="$(du "$SAVE_FILE" 2>/dev/null | awk '{print $1}')" ; [ -z "$DOWN" ] && DOWN=0
        r=$(((DOWN*10000)/SIZE))
        printf '%d\n' ${r%??}
    done | zenity --title "$TITLE" --text "$PROMPT_DOWNLOAD" --progress --auto-close
    while true ; do
        ACTIVE="$(ps aux | grep 'curl.*soportefirmadigital' | sed '/grep/d')"
        [ -z "$ACTIVE" ] && break
        sleep 0.5
    done | zenity --title "$TITLE" --text "$PROMPT_DOWNLOAD" --progress --pulsate --auto-close
    ACTIVE="$(ps aux | grep 'curl.*soportefirmadigital' | sed '/grep/d')"
    [ -n "$ACTIVE" ] && zenity --title "$TITLE" --text "$PROMPT_ERR_DOWNLOAD" --error && exit 1

    # Install dependencies, components and
    # certificates according to OS
    install_certs "$SAVE_FILE" | zenity --title "$TITLE" --text "$PROMPT_DEPS_INSTALL" --progress --pulsate --auto-close
    # zenity --title "$TITLE" --text "$PROMPT_ERR_DEPS_INSTALL" --error && exit 1

    zenity --title "$TITLE" --text "$PROMPT_END_SUCCESS" --info

else
    term_prompt "$TITLE" "$PROMPT_WELCOME" info && read -r NULL
    [ -n "$MISSING" ] && term_prompt "$TITLE" "$PROMPT_ERR_DEPS $MISSING" error && exit 1

    # Select file automatically or manually otherwise
    LIST="$(printf '1 - ClientesMAC_rev35.dmg           | macOSX 10.14 o superior
2 - ClientesLinux_DEB64_Rev25.zip   | Ubuntu 18.04 LTS o superior, Debian 10
3 - ClientesLinux_CentOS7_Rev6.zip  | CentOS 7
4 - ClientesLinux_RPM64_Rev24.zip   | Fedora 34 o superior, CentOS Stream 9')"
    [ -z "$FILE" ] && term_prompt "$TITLE" "$PROMPT_FILE" list "$LIST" && read -r FILE
    [ "$FILE" = "1" ] && FILE="ClientesMAC_rev35.dmg"
    [ "$FILE" = "2" ] && FILE="ClientesLinux_DEB64_Rev25.zip"
    [ "$FILE" = "3" ] && FILE="ClientesLinux_CentOS7_Rev6.zip"
    [ "$FILE" = "4" ] && FILE="ClientesLinux_RPM64_Rev24.zip"

    # Serial number is required for download
    term_prompt "$TITLE" "$PROMPT_SERIAL" entry && read -r SERIAL
    [ -z "$SERIAL" ] && term_prompt "$TITLE" "$PROMPT_ERR_SERIAL" error && exit 1
    # Generate tempkey & Define DOWNLOAD_URL
    TEMPKEY="$(download_iso "$FILE" "$SERIAL" | sed '/tempkey/!d;s/.*tempkey=//g;s/".*$//g')"
    [ -z "$TEMPKEY" ] && term_prompt "$TITLE" "$PROMPT_ERR_DOWNLOAD" error && exit 1
    DOWNLOAD_URL="https://soportefirmadigital.com/sfdj/getiso.aspx?tempkey=$TEMPKEY"
    # Define where to save file
    SAVE_DIR="/tmp/soportefirmadigital"
    SAVE_FILE="$SAVE_DIR/$FILE"
    mkdir -p "$SAVE_DIR"

    # Download file & show progress
    term_prompt "$TITLE" "$PROMPT_DOWNLOAD" info && echo
    curl "$DOWNLOAD_URL" -o "$SAVE_FILE" --progress-bar

    # Install dependencies, components and
    # certificates according to OS
    term_prompt "$TITLE" "$PROMPT_DEPS_INSTALL" info && echo
    install_certs "$SAVE_FILE"

    term_prompt "$TITLE" "$PROMPT_END_SUCCESS" info && echo

fi
